@@ -14,7 +14,7 @@ LSF = R6::R6Class("LSF",
             template$master = private$master
             private$job_id = template$job_name = paste0("cmq", self$id)
             if (log_worker)
-                template$log_file = paste0(values$job_name, ".log")
+                template$log_file = paste0(template$job_name, ".log")
 
             filled = infuser::infuse(LSF$template, template)
 
